@@ -1,4 +1,7 @@
 package Tenjin::Preprocessor;
+BEGIN {
+  $Tenjin::Preprocessor::VERSION = '0.062';
+}
 
 use strict;
 use warnings;
@@ -9,6 +12,10 @@ our @ISA = ('Tenjin::Template');
 
 Tenjin::Preprocessor - Preprocessing Tenjin templates
 
+=head1 VERSION
+
+version 0.062
+
 =head1 SYNOPSIS
 
 	used internally.
@@ -46,9 +53,7 @@ sub add_expr {
 	$self->SUPER::add_expr($bufref, $expr, $flag_escape);
 }
 
-__PACKAGE__;
-
-__END__
+1;
 
 =head1 SEE ALSO
 
@@ -56,8 +61,11 @@ L<Tenjin>, L<Tenjin::Template>.
 
 =head1 AUTHOR
 
-Tenjin is developed by Makoto Kuwata at L<http://www.kuwata-lab.com/tenjin/>.
-The CPAN version was tidied and CPANized from the original 0.0.2 source (with later updates from Makoto Kuwata's tenjin github repository) by Ido Perlmuter E<lt>ido@ido50.netE<gt>.
+The CPAN version of Tenjin was forked by Ido Perlmuter E<lt>ido at ido50.netE<gt>
+from version 0.0.2 of the original plTenjin, which is developed by Makoto Kuwata
+at L<http://www.kuwata-lab.com/tenjin/>.
+
+Development of Tenjin is done with github at L<http://github.com/ido50/Tenjin>.
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -84,4 +92,4 @@ Tenjin is licensed under the MIT license.
 	OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 	WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-=cut
+=cut
\ No newline at end of file
