@@ -1,11 +1,19 @@
 package Tenjin::Template;
+BEGIN {
+  $Tenjin::Template::VERSION = '0.062';
+}
 
 use strict;
 use warnings;
 use Fcntl qw/:flock/;
+use Carp;
 
 =head1 NAME
 
+
+=head1 VERSION
+
+version 0.062
 Tenjin::Template - A Tenjin template object, either built from a file
 or from memory.
 
@@ -80,13 +88,14 @@ C<$var> with C<< $var->{str} >>.
 =cut
 
 sub new {
-	my ($class, $filename, $opts) = @_;
+	my ($class, $filename, $template_name, $opts) = @_;
 
 	my $escapefunc = defined($opts) && exists($opts->{escapefunc}) ? $opts->{escapefunc} : undef;
 	my $rawclass   = defined($opts) && exists($opts->{rawclass}) ? $opts->{rawclass} : undef;
 
 	my $self = bless {
 		'filename'   => $filename,
+		'name'       => $template_name,
 		'script'     => undef,
 		'escapefunc' => $escapefunc,
 		'rawclass'   => $rawclass,
@@ -103,34 +112,12 @@ sub new {
 
 Renders the template, possibly with a context hash-ref, and returns the
 rendered output. If errors have occured when rendering the template (which
-might happen since templates have and are Perl code), then the error
-will trigger a C<die>!
-
-If you do not want to C<die> when encountering errors in templates, or wish
-to cache the errors yourself (as the L<Tenjin> engine does itself), then you
-need to call L<_render()|_render( [$_context] )> instead.
+might happen since templates have and are Perl code), then this method
+will croak.
 
 =cut
 
 sub render {
-	my $self = shift;
-
-	my $output = $self->_render(@_);
-	if ($@) {  # error happened
-		my $template_filename = $self->{filename};
-		die "Tenjin::Template: \"Error rendering " . $self->{filename} . "\"\n", $@;
-	}
-	return $output;
-}
-
-=head2 _render( [$_context] )
-
-Renders the template, possibly with a context hash-ref, and returns the
-rendered output.
-
-=cut
-
-sub _render {
 	my ($self, $_context) = @_;
 
 	$_context ||= {};
@@ -138,12 +125,17 @@ sub _render {
 	if ($self->{func}) {
 		return $self->{func}->($_context);
 	} else {
-		if (ref($_context) eq 'HASH') {
-			$_context = $Tenjin::CONTEXT_CLASS->new($_context);
-		}
+		$_context = $Tenjin::CONTEXT_CLASS->new($_context) if ref $_context eq 'HASH';			
+
 		my $script = $self->{script};
 		$script = $_context->_build_decl() . $script unless $self->{args};
-		return $_context->evaluate($script, $self->{filename});
+		
+		# rendering is actually done inside the context object
+		# with the evaluate method. We pass either the name of
+		# the template or the filename of the template for debug
+		# purposes
+		
+		return $_context->evaluate($script, $self->{filename} || $self->{name});
 	}
 }
 
@@ -275,8 +267,8 @@ sub hook_stmt {
 			foreach my $arg (split(/,/, $argstr)) {
 				$arg =~ s/(^\s+|\s+$)//g;
 				next unless $arg;
-				$arg =~ m/\A([\$\@\%])?([a-zA-Z_]\w*)\Z/ or die("Tenjin::Template: \"$arg: invalid template argument.\"");
-				die "Tenjin::Template: \"$arg: only '\$var' is available for template argument.\"" unless (!$1 || $1 eq '$');
+				$arg =~ m/\A([\$\@\%])?([a-zA-Z_]\w*)\Z/ or croak "[Tenjin] $arg: invalid template argument.";
+				croak "[Tenjin] $arg: only '\$var' is available for template argument." unless (!$1 || $1 eq '$');
 				my $name = $2;
 				push(@args, $name);
 				push(@declares, "my \$$name = \$_context->{$name}; ");
@@ -405,7 +397,7 @@ sub stop_text_part {
 sub add_text {
 	my ($self, $bufref, $text) = @_;
 
-	return undef unless $text;
+	return unless $text;
 	$text =~ s/[`\\]/\\$&/g;
 	my $is_start = $bufref->[0] =~ / \$_buf \.= \Z/;
 	$bufref->[0] .= $is_start ? "q`$text`" : " . q`$text`";
@@ -467,11 +459,10 @@ sub compile {
 	my $self = shift;
 
 	if ($self->{args}) {
-		my $func = $Tenjin::CONTEXT_CLASS->to_func($self->{script}, $self->{filename});
-		die "Tenjin::Template: \"Error compiling " . $self->{filename} . "\"\n", $@ if $@;
-		return $self->{func} = $func;
+		$self->{func} = $Tenjin::CONTEXT_CLASS->to_func($self->{script}, $self->{name});
+		return $self->{func};
 	}
-	return undef;
+	return;
 }
 
 =head2 escaped_expr( $expr )
@@ -505,7 +496,7 @@ file will be locked for reading.
 sub _read_file {
 	my ($self, $filename, $lock_required) = @_;
 
-	open(IN, $filename) or die("Tenjin::Template: Can't open $filename for reading: $!");
+	open(IN, $filename) or croak "[Tenjin] Can't open $filename for reading: $!";
 	binmode(IN);
 	flock(IN, LOCK_SH) if $lock_required;
 
@@ -528,16 +519,14 @@ locked exclusively when writing.
 sub _write_file {
 	my ($self, $filename, $content, $lock_required) = @_;
 
-	open(OUT, ">$filename") or die("Tenjin::Template: \"Can't open $filename for writing: $!\"");
+	open(OUT, ">$filename") or croak "[Tenjin] Can't open $filename for writing: $!";
 	binmode(OUT);
 	flock(OUT, LOCK_EX) if $lock_required;
 	print OUT $content;
 	close(OUT);
 }
 
-__PACKAGE__;
-
-__END__
+1;
 
 =head1 SEE ALSO
 
@@ -545,8 +534,11 @@ L<Tenjin>.
 
 =head1 AUTHOR
 
-Tenjin is developed by Makoto Kuwata at L<http://www.kuwata-lab.com/tenjin/>.
-The CPAN version was tidied and CPANized from the original 0.0.2 source (with later updates from Makoto Kuwata's tenjin github repository) by Ido Perlmuter E<lt>ido@ido50.netE<gt>.
+The CPAN version of Tenjin was forked by Ido Perlmuter E<lt>ido at ido50.netE<gt>
+from version 0.0.2 of the original plTenjin, which is developed by Makoto Kuwata
+at L<http://www.kuwata-lab.com/tenjin/>.
+
+Development of Tenjin is done with github at L<http://github.com/ido50/Tenjin>.
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -573,4 +565,4 @@ Tenjin is licensed under the MIT license.
 	OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 	WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-=cut
+=cut
\ No newline at end of file
